"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const chalk_1 = require("chalk");
const fs = require("fs-extra");
const deploy_1 = require("../../service/deploy");
const getFileName_1 = require("../../service/getFileName");
const getNameSpacePrefix_1 = require("../../service/getNameSpacePrefix");
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages('mo-dx-plugin', 'org');
class ApexDeploy extends command_1.SfdxCommand {
    async run() {
        this.ux.startSpinner(chalk_1.default.bold.yellowBright('Saving ....'));
        const conn = this.org.getConnection();
        const namespacePrefix = await getNameSpacePrefix_1.getNameSpacePrefix(conn);
        const filebody = await fs.readFile(this.flags.filepath, 'utf8');
        // get the apex class Id using the class Name
        const className = getFileName_1.getFileName(this.flags.filepath, '.cls');
        const apexclass = await conn.tooling.sobject('Apexclass').find({
            Name: className,
            NameSpacePrefix: namespacePrefix
        });
        // logic to update apex class
        if (apexclass.length > 0) {
            const classId = apexclass[0].Id;
            const deployAction = new deploy_1.Deploy('ApexContainer', 'ApexClassMember', classId, filebody, conn);
            const deployResult = await deployAction.deployMetadata();
            if (deployResult.success) {
                this.ux.stopSpinner(chalk_1.default.bold.greenBright('Apex Class Successfully Updated'));
                return '';
            }
            else {
                this.ux.stopSpinner(chalk_1.default.bold.redBright('Apex Class Update Failed'));
                if (typeof deployResult.error !== 'undefined') {
                    console.log(chalk_1.default.bold.redBright(deployResult.error));
                }
            }
        }
        else {
            // logic to create an apex class
            // Create Container AsyncRequest Object
            const apexClass = {
                Body: filebody,
                NamespacePrefix: namespacePrefix
            };
            const apexSaveResult = await conn.tooling.sobject('ApexClass').create(apexClass);
            if (apexSaveResult.success) {
                this.ux.stopSpinner(chalk_1.default.bold.green('Apex Class Successfully Created'));
                return '';
            }
            else {
                for (const error of apexSaveResult.errors) {
                    console.log(chalk_1.default.redBright(error));
                }
                this.ux.stopSpinner(chalk_1.default.bold.red('Apex Class Creation Failed'));
            }
        }
    }
}
ApexDeploy.description = messages.getMessage('commandDescription');
ApexDeploy.examples = [
    '$ sfdx deploy:apex -p filepath'
];
ApexDeploy.flagsConfig = {
    // flag with a value (-n, --name=VALUE)
    filepath: { type: 'string', char: 'p', description: 'file path' }
};
// Comment this out if your command does not require an org username
ApexDeploy.requiresUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
ApexDeploy.requiresProject = true;
exports.default = ApexDeploy;
//# sourceMappingURL=apex.js.map