"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const chalk_1 = require("chalk");
const fs = require("fs-extra");
const deploy_1 = require("../../service/deploy");
const getFileName_1 = require("../../service/getFileName");
const getNameSpacePrefix_1 = require("../../service/getNameSpacePrefix");
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages('mo-dx-plugin', 'org');
class TriggerDeploy extends command_1.SfdxCommand {
    async run() {
        this.ux.startSpinner(chalk_1.default.bold.yellowBright('Saving ....'));
        const conn = this.org.getConnection();
        const namespacePrefix = await getNameSpacePrefix_1.getNameSpacePrefix(conn);
        const filebody = await fs.readFile(this.flags.filepath, 'utf8');
        const tableName = filebody.split(' ')[3];
        // get the trigger Id using the trigger Name
        const triggerName = getFileName_1.getFileName(this.flags.filepath, '.trigger');
        const apextrigger = await conn.tooling.sobject('Apextrigger').find({
            Name: triggerName,
            NameSpacePrefix: namespacePrefix
        });
        // logic to update apex class
        if (apextrigger.length > 0) {
            const triggerId = apextrigger[0].Id;
            const deployAction = new deploy_1.Deploy('TriggerContainer', 'ApexTriggerMember', triggerId, filebody, conn);
            const deployResult = await deployAction.deployMetadata();
            if (deployResult.success) {
                this.ux.stopSpinner(chalk_1.default.bold.greenBright('Trigger Successfully Updated'));
                return '';
            }
            else {
                this.ux.stopSpinner(chalk_1.default.bold.redBright('Trigger Update Failed'));
                if (typeof deployResult.error !== 'undefined') {
                    console.log(chalk_1.default.bold.redBright(deployResult.error));
                }
            }
        }
        else {
            // logic to create an apex class
            // Create Container AsyncRequest Object
            const apexTrigger = {
                Body: filebody,
                Name: triggerName,
                TableEnumOrId: tableName,
                NamespacePrefix: namespacePrefix
            };
            const apexSaveResult = await conn.tooling.sobject('ApexTrigger').create(apexTrigger);
            if (apexSaveResult.success) {
                this.ux.stopSpinner(chalk_1.default.bold.green('Trigger Successfully Created'));
                return '';
            }
            else {
                for (const error of apexSaveResult.errors) {
                    console.log(chalk_1.default.redBright(error));
                }
                this.ux.stopSpinner(chalk_1.default.bold.red('Trigger Creation Failed'));
            }
        }
    }
}
TriggerDeploy.description = messages.getMessage('commandDescription');
TriggerDeploy.examples = [
    '$ sfdx deploy:trigger -p filepath'
];
TriggerDeploy.flagsConfig = {
    // flag with a value (-n, --name=VALUE)
    filepath: { type: 'string', char: 'p', description: 'file path' }
};
// Comment this out if your command does not require an org username
TriggerDeploy.requiresUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
TriggerDeploy.requiresProject = true;
exports.default = TriggerDeploy;
//# sourceMappingURL=trigger.js.map