"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const chalk_1 = require("chalk");
const fs = require("fs-extra");
const deploy_1 = require("../../service/deploy");
const getFileName_1 = require("../../service/getFileName");
const getNameSpacePrefix_1 = require("../../service/getNameSpacePrefix");
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages('mo-dx-plugin', 'org');
class VfDeploy extends command_1.SfdxCommand {
    async run() {
        this.ux.startSpinner(chalk_1.default.bold.yellowBright('Saving ....'));
        const conn = this.org.getConnection();
        const namespacePrefix = await getNameSpacePrefix_1.getNameSpacePrefix(conn);
        const filebody = await fs.readFile(this.flags.filepath, 'utf8');
        // get the apex class Id using the class Name
        const pageName = getFileName_1.getFileName(this.flags.filepath, '.page');
        const apexpages = await conn.tooling.sobject('ApexPage').find({
            Name: pageName,
            NameSpacePrefix: namespacePrefix
        });
        // logic to update visualforce page
        if (apexpages.length > 0) {
            const pageId = apexpages[0].Id;
            const deployAction = new deploy_1.Deploy('VfContainer', 'ApexPageMember', pageId, filebody, conn);
            const deployResult = await deployAction.deployMetadata();
            if (deployResult.success) {
                this.ux.stopSpinner(chalk_1.default.bold.greenBright('Visualforce Page Successfully Updated'));
                return '';
            }
            else {
                this.ux.stopSpinner(chalk_1.default.bold.redBright('Visualforce Page Update Failed'));
                if (typeof deployResult.error !== 'undefined') {
                    console.log(chalk_1.default.bold.redBright(deployResult.error));
                }
            }
        }
        else {
            // logic to create an VF page
            // Create Container AsyncRequest Object
            const vfPage = {
                Name: pageName,
                Markup: filebody,
                Masterlabel: pageName + 'Label'
            };
            const vfSaveResult = await conn.tooling.sobject('ApexPage').create(vfPage);
            if (vfSaveResult.success) {
                this.ux.stopSpinner(chalk_1.default.bold.green('Visualforce Page Successfully Created'));
                return '';
            }
            else {
                for (const error of vfSaveResult.errors) {
                    console.log(chalk_1.default.redBright(error));
                }
                this.ux.stopSpinner(chalk_1.default.bold.red('Visualforce Page Creation Failed'));
            }
        }
    }
}
VfDeploy.description = messages.getMessage('commandDescription');
VfDeploy.examples = [
    '$ sfdx deploy:vf -p filepath'
];
VfDeploy.flagsConfig = {
    // flag with a value (-n, --name=VALUE)
    filepath: { type: 'string', char: 'p', description: 'file path' }
};
// Comment this out if your command does not require an org username
VfDeploy.requiresUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
VfDeploy.requiresProject = true;
exports.default = VfDeploy;
//# sourceMappingURL=vf.js.map