"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@salesforce/command");
const chalk_1 = require("chalk");
const fs = require("fs-extra");
const deploy_1 = require("../../service/deploy");
const getFileName_1 = require("../../service/getFileName");
const getNameSpacePrefix_1 = require("../../service/getNameSpacePrefix");
// Initialize Messages with the current plugin directory
command_1.core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = command_1.core.Messages.loadMessages('mo-dx-plugin', 'org');
class ApexComponentDeploy extends command_1.SfdxCommand {
    async run() {
        this.ux.startSpinner(chalk_1.default.bold.yellowBright('Saving ....'));
        const conn = this.org.getConnection();
        const namespacePrefix = await getNameSpacePrefix_1.getNameSpacePrefix(conn);
        const filebody = await fs.readFile(this.flags.filepath, 'utf8');
        // get the apex class Id using the class Name
        const vfComponentName = getFileName_1.getFileName(this.flags.filepath, '.component');
        const apexVFComponents = await conn.tooling.sobject('ApexComponent').find({
            Name: vfComponentName,
            NameSpacePrefix: namespacePrefix
        });
        // logic to update visualforce page
        if (apexVFComponents.length > 0) {
            const apexPageComponentId = apexVFComponents[0].Id;
            const deployAction = new deploy_1.Deploy('VfComponent', 'ApexComponentMember', apexPageComponentId, filebody, conn);
            const deployResult = await deployAction.deployMetadata();
            if (deployResult.success) {
                this.ux.stopSpinner(chalk_1.default.bold.greenBright('Visualforce Component Successfully Updated'));
                return '';
            }
            else {
                this.ux.stopSpinner(chalk_1.default.bold.redBright('Visualforce Component Update Failed'));
                if (typeof deployResult.error !== 'undefined') {
                    console.log(chalk_1.default.bold.redBright(deployResult.error));
                }
            }
        }
        else {
            // logic to create an VF page
            // Create Container AsyncRequest Object
            const vfComponent = {
                Name: vfComponentName,
                Markup: filebody,
                Masterlabel: vfComponentName + 'Label'
            };
            const vfComponentSaveResult = await conn.tooling.sobject('ApexComponent').create(vfComponent);
            if (vfComponentSaveResult.success) {
                this.ux.stopSpinner(chalk_1.default.bold.green('Visualforce Component Successfully Created'));
                return '';
            }
            else {
                for (const error of vfComponentSaveResult.errors) {
                    console.log(chalk_1.default.redBright(error));
                }
                this.ux.stopSpinner(chalk_1.default.bold.red('Visualforce Component Creation Failed'));
            }
        }
    }
}
ApexComponentDeploy.description = messages.getMessage('commandDescription');
ApexComponentDeploy.examples = [
    '$ sfdx deploy:vfcomponent -p filepath'
];
ApexComponentDeploy.flagsConfig = {
    // flag with a value (-n, --name=VALUE)
    filepath: { type: 'string', char: 'p', description: 'file path' }
};
// Comment this out if your command does not require an org username
ApexComponentDeploy.requiresUsername = true;
// Set this to true if your command requires a project workspace; 'requiresProject' is false by default
ApexComponentDeploy.requiresProject = true;
exports.default = ApexComponentDeploy;
//# sourceMappingURL=vfcomponent.js.map