"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const chalk_1 = require("chalk");
const delay_1 = require("./delay");
const toolingQuery_1 = require("./toolingQuery");
async function createDeployRequest(containerId, ischeck, conn) {
    // Create Container AsyncRequest Object
    const containerasynRequestReq = {
        IsCheckOnly: ischeck,
        MetadataContainerId: containerId
    };
    const containerAsyncResult = await conn.tooling.sobject('ContainerAsyncRequest').create(containerasynRequestReq);
    let containerRequestResponse = {};
    if (containerAsyncResult.success) {
        const asyncResultId = containerAsyncResult.id;
        let containerRequestQuery = 'Select Id, State, ErrorMsg, DeployDetails FROM ContainerAsyncRequest where Id =\'';
        containerRequestQuery = containerRequestQuery + asyncResultId + '\'';
        containerRequestResponse = await toolingQuery_1.executeToolingQuery(containerRequestQuery, conn);
        if (containerRequestResponse.records.length > 0) {
            let containerAsyncRequestRes = containerRequestResponse.records[0];
            while (containerAsyncRequestRes.State.toLocaleLowerCase() === 'queued') {
                await delay_1.delay(1000);
                containerRequestResponse = await toolingQuery_1.executeToolingQuery(containerRequestQuery, conn);
                containerAsyncRequestRes = containerRequestResponse.records[0];
            }
            switch (containerAsyncRequestRes.State) {
                case 'Invalidated':
                    console.log(chalk_1.default.redBright(JSON.stringify(containerAsyncRequestRes.DeployDetails.componentFailures)));
                    break;
                case 'Completed':
                    break;
                case 'Failed':
                    for (const error of containerAsyncRequestRes.DeployDetails.componentFailures) {
                        console.log(chalk_1.default.redBright('Line:' + error.lineNumber + ' Column:' + error.columnNumber + ' Error Description:' + error.problem + '\r\n'));
                    }
                    break;
                case 'Error':
                    console.log(chalk_1.default.redBright(JSON.stringify(containerAsyncRequestRes.DeployDetails.componentFailures)));
                    break;
                case 'Aborted':
                    console.log('Aborted..');
                    break;
            }
        }
    }
    return containerRequestResponse;
}
exports.createDeployRequest = createDeployRequest;
//# sourceMappingURL=containerAsyncRequest.js.map